<!DOCTYPE TS><TS>
<defaultcodec>iso8859-1</defaultcodec>
<context>
    <name>EditorToolBar</name>
    <message>
        <source>Cut (Ctrl + X)</source>
        <translation>Zarezat&apos; (Ctrl + X)</translation>
    </message>
    <message>
        <source>Copy (Ctrl + C)</source>
        <translation>Skopirovat&apos; (Ctrl + C)</translation>
    </message>
    <message>
        <source>Paste (Ctrl + V)</source>
        <translation>Vkvasit&apos; (Ctrl + V)</translation>
    </message>
    <message>
        <source>Undo (Ctrl + Z)</source>
        <translation>Vernutsya (Ctrl + Z)</translation>
    </message>
    <message>
        <source>Redo (Ctrl + R)</source>
        <translation>Peredelat&apos; (Ctrl + R)</translation>
    </message>
    <message>
        <source>Power (Ctrl + 6)</source>
        <translation>Stepen&apos; (Ctrl + 6)</translation>
    </message>
    <message>
        <source>Fraction (Ctrl + /)</source>
        <translation>Drob&apos; (Ctrl + /)</translation>
    </message>
    <message>
        <source>Root (Ctrl + 2)</source>
        <translation>Koren&apos; (Ctrl + 2)</translation>
    </message>
    <message>
        <source>Parentheses (()</source>
        <translation>Skobki (()</translation>
    </message>
    <message>
        <source>Absolute value (|)</source>
        <translation>Absolyutnaya velichina (|)</translation>
    </message>
</context>
<context>
    <name>G_measureObject</name>
    <message>
        <source>Distance {%1} {%2}</source>
        <translation>Rasstoyaniye ot {%1} do {%2}</translation>
    </message>
    <message>
        <source>Circumference {%1}</source>
        <translation>Dlina okruzhnosti {%1}</translation>
    </message>
    <message>
        <source>Length {%1}</source>
        <translation>Dlina {%1}</translation>
    </message>
    <message>
        <source>Radius {%1}</source>
        <translation>Radius {%1}</translation>
    </message>
    <message>
        <source>Arc Angle {%1}</source>
        <translation>Ugol Dugi {%1}</translation>
    </message>
    <message>
        <source>Angle {%1}{%2}{%3}</source>
        <translation>Ugol {%1}{%2}{%3}</translation>
    </message>
    <message>
        <source>Ratio {%1}/{%2}</source>
        <translation>Otnosheniye {%1}/{%2}</translation>
    </message>
    <message>
        <source>Slope {%1}</source>
        <translation>Naklon {%1}</translation>
    </message>
    <message>
        <source>Area {%1}</source>
        <translation>Ploshad&apos; {%1}</translation>
    </message>
</context>
<context>
    <name>G_ref</name>
    <message>
        <source>Point</source>
        <translation>Tochka</translation>
    </message>
    <message>
        <source>Segment</source>
        <translation>Otrezok</translation>
    </message>
    <message>
        <source>Ray</source>
        <translation>Luch</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>Liniya</translation>
    </message>
    <message>
        <source>Circle</source>
        <translation>Krug</translation>
    </message>
    <message>
        <source>Arc</source>
        <translation>Duga</translation>
    </message>
    <message>
        <source>Polygon</source>
        <translation>Mnogougol&apos;nik</translation>
    </message>
    <message>
        <source>Circle Interior</source>
        <translation>Vnutrennost&apos; kruga</translation>
    </message>
    <message>
        <source>Arc Sector</source>
        <translation>Sektor</translation>
    </message>
    <message>
        <source>Arc Segment</source>
        <translation>Segment</translation>
    </message>
    <message>
        <source>Locus</source>
        <translation>Puchok</translation>
    </message>
    <message>
        <source>Measurement</source>
        <translation>Izmereniye</translation>
    </message>
    <message>
        <source>Calculation</source>
        <translation>Vychisleniye</translation>
    </message>
    <message>
        <source>Annotation</source>
        <translation>Text</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Neizvestno chto</translation>
    </message>
</context>
<context>
    <name>G_valueObject</name>
    <message>
        <source>undefined</source>
        <translation>neopredelenno</translation>
    </message>
</context>
<context>
    <name>KSegCalculateEditor</name>
    <message>
        <source>Value is undefined</source>
        <translation>Znacheniye neopredelenno</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Otmena</translation>
    </message>
    <message>
        <source>Value is %1</source>
        <translation>Znacheniye ravno %1</translation>
    </message>
    <message>
        <source>Insert %1 %2</source>
        <comment>For example, &quot;Insert Measurement M1&quot;</comment>
        <translation>Vstavit&apos; %1 %2</translation>
    </message>
    <message>
        <source>Ready</source>
        <translation>Ya gotov</translation>
    </message>
</context>
<context>
    <name>KSegConstructionList</name>
    <message>
        <source>Loop on %1</source>
        <translation>Zatsiklis&apos; na %1</translation>
    </message>
    <message>
        <source>or</source>
        <translation>ili</translation>
    </message>
    <message>
        <source>final</source>
        <translation>konechnoe</translation>
    </message>
    <message>
        <source>initial</source>
        <translation>nachal&apos;noe</translation>
    </message>
    <message>
        <source>not constructed</source>
        <translation>ne postroenno</translation>
    </message>
    <message>
        <source>doesn&apos;t exist</source>
        <translation>ne sushestvuet</translation>
    </message>
    <message>
        <source>hidden</source>
        <translation>skryto</translation>
    </message>
    <message>
        <source>Given</source>
        <translation>Dano</translation>
    </message>
    <message>
        <source>Final</source>
        <translation>Konechnoe</translation>
    </message>
    <message>
        <source>Initial</source>
        <translation>Nachal&apos;noe</translation>
    </message>
    <message>
        <source>%1 is the translation of %2 by the vector from %3 to %4</source>
        <translation>%1 eto translatsiya %2 po vectory ot %3 do %4</translation>
    </message>
    <message>
        <source>%1 is the rotation of %2 about %3 by angle %4</source>
        <translation>%1 eto vrasheniye %2 vokrug %3 po uglu %4</translation>
    </message>
    <message>
        <source>%1 is the image of %2 scaled about %3 by the ratio %4:%5</source>
        <translation>%1 eto %2 pod otnosheniyem %4:%5 vokrug %3</translation>
    </message>
    <message>
        <source>%1 is the image of %2 scaled about %3 by ratio %4</source>
        <translation>%1 eto %2 pod otnosheniyem %4 vokrug %3</translation>
    </message>
    <message>
        <source>%1 is the reflection of %2 about %3</source>
        <translation>%1 eto otrazheniye %2 ob %3</translation>
    </message>
    <message>
        <source>%1 is free</source>
        <translation>%1 svobodna</translation>
    </message>
    <message>
        <source>%1 is on %2</source>
        <translation>%1 lezhit na %2</translation>
    </message>
    <message>
        <source>%1 is the intersection of %2 and %3</source>
        <translation>%1 eto peresecheniye %2 i %3</translation>
    </message>
    <message>
        <source>%1 is the 2nd intersection of %2 and %3</source>
        <translation>%1 eto vtoroe peresecheniye %2 i %3</translation>
    </message>
    <message>
        <source>%1 is the midpoint of %2</source>
        <translation>%1 eto seredina %2</translation>
    </message>
    <message>
        <source>%1 has endpoints %2 and %3</source>
        <translation>%1 imeet konechniye tochki %2 i %3</translation>
    </message>
    <message>
        <source>%1 is from %2 through %3</source>
        <translation>%1 iz %2 cherez %3</translation>
    </message>
    <message>
        <source>%1 bisects angle %2 %3 %4</source>
        <translation>%1 delit ugol %2 %3 %4 na dva</translation>
    </message>
    <message>
        <source>%1 is between %2 and %3</source>
        <translation>%1 prohodit cherez %2 i %3</translation>
    </message>
    <message>
        <source>%1 is parallel to %2 through %3</source>
        <translation>%1 parallel&apos;na %2 cherez %3</translation>
    </message>
    <message>
        <source>%1 is perpendicular to %2 through %3</source>
        <translation>%1 perpendikulyarna %2 cherez %3</translation>
    </message>
    <message>
        <source>%1 is centered at %2 and passes through %3</source>
        <translation>%1 imeet centr v %2 i prohodit cherez %3</translation>
    </message>
    <message>
        <source>%1 has center at %2 and radius %3</source>
        <translation>%1 imeet centr v %2 i radius %3</translation>
    </message>
    <message>
        <source>%1 passes through points %2, %3, and %4</source>
        <translation>%1 prohodit cherez tochki %2, %3, i %4</translation>
    </message>
    <message>
        <source>%1 is traced by %2, driven by %3</source>
        <translation>%1 risuyetsya %2, kogda %3 begaet</translation>
    </message>
    <message>
        <source>%1 involves %2</source>
        <translation>%1 ispol&apos;zuyet %2</translation>
    </message>
    <message>
        <source>%1 is the distance between %2 and %3</source>
        <translation>%1 rasstoyaniye mezhdu %2 i %3</translation>
    </message>
    <message>
        <source>%1 is the length of %2</source>
        <translation>%1 eto dlina %2</translation>
    </message>
    <message>
        <source>%1 is the angle of %2</source>
        <translation>%1 eto ugol %2</translation>
    </message>
    <message>
        <source>%1 is the angle between points %1, %2, and %3</source>
        <translation>%1 eto ugol mezhdu tochkami %1, %2, i %3</translation>
    </message>
    <message>
        <source>%1 is the ratio of %2 to %3</source>
        <translation>%1 eto otnosheniye %2 k %3</translation>
    </message>
    <message>
        <source>%1 is the slope of %2</source>
        <translation>%1 eto naklon %2</translation>
    </message>
    <message>
        <source>%1 is the area of %2</source>
        <translation>%1 eto ploshad&apos; %2</translation>
    </message>
    <message>
        <source>%1 is defined by %2</source>
        <translation>%1 opredelen cherez %2</translation>
    </message>
    <message>
        <source>%1 has vertices at points %2</source>
        <translation>%1 imeet vershiny v tochkah %2</translation>
    </message>
    <message>
        <source>%1 is the radius of %2</source>
        <translation>%1 eto radius %2</translation>
    </message>
    <message>
        <source>%1 is the endpoint of %2</source>
        <translation>%1 konechnaya tochka %2</translation>
    </message>
    <message>
        <source>%1 is the 2nd endpoint of %2</source>
        <translation>%1 vtoraya konechnaya tochka %2</translation>
    </message>
    <message>
        <source>%1 is the center of %2</source>
        <translation>%1 eto centr %2</translation>
    </message>
</context>
<context>
    <name>KSegDocument</name>
    <message>
        <source>Cancel</source>
        <translation>Otmena</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
</context>
<context>
    <name>KSegPreferencesDialog</name>
    <message>
        <source>KSEG Preferences</source>
        <translation>KSEGovskie Predpochteniya</translation>
    </message>
    <message>
        <source>Background Color</source>
        <translation>Cvet Fona</translation>
    </message>
    <message>
        <source>Default Foreground Color</source>
        <translation>Nachal&apos;nyj Cvet Objektov</translation>
    </message>
    <message>
        <source>Selection Display</source>
        <translation>Kak Risovat&apos; Vybrannye Objekty</translation>
    </message>
    <message>
        <source>Border Selection</source>
        <translation>Risovat&apos; Bordyurom</translation>
    </message>
    <message>
        <source>Blinking Selection</source>
        <translation>Risovat&apos; Miganiem</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Otmena</translation>
    </message>
</context>
<context>
    <name>KSegRecursionDialog</name>
    <message>
        <source>Enter recursion depth:</source>
        <translation>Vvediti glubinu rekursii:</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Otmena</translation>
    </message>
    <message>
        <source>Will produce too many objects.</source>
        <translation>Budet slishkom mnogo objectov.</translation>
    </message>
    <message>
        <source>Will produce %1 objects.</source>
        <translation>Budet %1 objectov.</translation>
    </message>
</context>
<context>
    <name>KSegSampleChangeDialog</name>
    <message>
        <source>Samples in locus:</source>
        <translation>Tochek podsheta v puchke:</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Otmena</translation>
    </message>
</context>
<context>
    <name>KSegSelectionGroupDialog</name>
    <message>
        <source>Select</source>
        <translation>Vybrat&apos;</translation>
    </message>
    <message>
        <source>Deselect</source>
        <translation>Ubrat&apos; Vybor</translation>
    </message>
    <message>
        <source>New Group</source>
        <translation>Novaya Gruppa</translation>
    </message>
    <message>
        <source>Delete Group</source>
        <translation>Udalit&apos; Gruppu</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Zakryt&apos;</translation>
    </message>
    <message>
        <source>Affect
Invisible
Items</source>
        <translation>Trogat&apos;
Nevidimye
Objekty</translation>
    </message>
    <message>
        <source>Hold SHIFT and click to add to current selection</source>
        <translation>Derzhite SHIFT i clicknite chto-b dobavit&apos; k vybory</translation>
    </message>
    <message>
        <source>Whether the &quot;All &lt;Type&gt;&quot; groups also (de)select invisible objects</source>
        <translation>Vybirayut-li gruppy tipa &quot;Vse &lt;Tip&gt;&quot; nevidimye objekty</translation>
    </message>
    <message>
        <source>All Points</source>
        <translation>Vse tochki</translation>
    </message>
    <message>
        <source>All Segments</source>
        <translation>Vse Otrezki</translation>
    </message>
    <message>
        <source>All Rays</source>
        <translation>Vse Luchi</translation>
    </message>
    <message>
        <source>All Lines</source>
        <translation>Vse Linii</translation>
    </message>
    <message>
        <source>All Circles</source>
        <translation>Vse Krugi</translation>
    </message>
    <message>
        <source>All Arcs</source>
        <translation>Vse Dugi</translation>
    </message>
    <message>
        <source>All Polygons</source>
        <translation>Vse Mnogougol&apos;niki</translation>
    </message>
    <message>
        <source>All Circle Interiors</source>
        <translation>Vse Vnutrennosti Krugov</translation>
    </message>
    <message>
        <source>All Arc Sectors</source>
        <translation>Vse Sektory</translation>
    </message>
    <message>
        <source>All Arc Segments</source>
        <translation>Vse Segmenty</translation>
    </message>
    <message>
        <source>All Loci</source>
        <translation>Vse Puchki</translation>
    </message>
    <message>
        <source>All Measurements</source>
        <translation>Vse Izmereniya</translation>
    </message>
    <message>
        <source>All Calculations</source>
        <translation>Vse Vychisleniya</translation>
    </message>
    <message>
        <source>Enter new group name:</source>
        <translation>Vvediti nazvanie novoy gruppy:</translation>
    </message>
    <message>
        <source>Are you sure you want to delete the selected group(s)?</source>
        <translation>Tochno hochesh udalit&apos; vybrannye gruppy?</translation>
    </message>
</context>
<context>
    <name>KSegView</name>
    <message>
        <source>Untitled</source>
        <translation>Nenazvan</translation>
    </message>
    <message>
        <source>Ready</source>
        <translation>Ya gotov</translation>
    </message>
    <message>
        <source>Move label of %1 %2</source>
        <comment>E.g. &quot;Move label of Point P1&quot;</comment>
        <translation>Podvinut&apos; nazvaniye %1 %2</translation>
    </message>
    <message>
        <source>Select %1 %2</source>
        <translation>Vybrat&apos; %1 %2</translation>
    </message>
    <message>
        <source>Deselect %1 %2</source>
        <translation>Ubrat&apos; vybor %1 %2</translation>
    </message>
    <message>
        <source>Also select %1 %2</source>
        <translation>Takzhe vybrat&apos; %1 %2</translation>
    </message>
    <message>
        <source>Move Selected Objects</source>
        <translation>Podvinut&apos; Vybrannye Objekty</translation>
    </message>
    <message>
        <source>Reconstrain %1 %2 to be free</source>
        <translation>Pereopredelit&apos; %1 %2 kak svobodnuyu</translation>
    </message>
    <message>
        <source>Reconstrain %1 %2 to %3 %4</source>
        <comment>E.g., &quot;Reconstrain Point P1 to Line l1&quot;</comment>
        <translation>Pereopredelit&apos; %1 %2 chto-by lezhala na %3 %4</translation>
    </message>
    <message>
        <source>Reconstrain %1 %2 to the intersection of %3 %4 and %5 %6</source>
        <translation>Pereopredelit&apos; %1 %2 chto-b lezhala na peresechenii %3 %4 i %5 %6</translation>
    </message>
    <message>
        <source>Pan</source>
        <translation>Dviganie Vida</translation>
    </message>
    <message>
        <source>Zoom</source>
        <translation>Uvelichenie</translation>
    </message>
</context>
<context>
    <name>KSegWindow</name>
    <message>
        <source>kseg: Untitled</source>
        <translation>kseg: Nenazvan</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Fayl</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>R&amp;edaktirovanie</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Novoye</translation>
    </message>
    <message>
        <source>Meas&amp;ure</source>
        <translation>I&amp;zmereniye</translation>
    </message>
    <message>
        <source>&amp;Transform</source>
        <translation>&amp;Transformatsiya</translation>
    </message>
    <message>
        <source>Pla&amp;y</source>
        <translation>Proigra&amp;y</translation>
    </message>
    <message>
        <source>Const&amp;ruction</source>
        <translation>Post&amp;roeniye</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>Pomos&amp;h</translation>
    </message>
    <message>
        <source>&amp;New Sketch</source>
        <translation>&amp;Noviy Resunok</translation>
    </message>
    <message>
        <source>Ne&amp;w Construction</source>
        <translation>Novoe Postroeni&amp;ye</translation>
    </message>
    <message>
        <source>New &amp;View</source>
        <translation>Noviy &amp;Vid</translation>
    </message>
    <message>
        <source>&amp;Open...</source>
        <translation>&amp;Otkryt&apos;...</translation>
    </message>
    <message>
        <source>&amp;Save</source>
        <translation>Zapi&amp;sat&apos;</translation>
    </message>
    <message>
        <source>Save &amp;As...</source>
        <translation>Z&amp;apisat&apos; Kak...</translation>
    </message>
    <message>
        <source>&amp;Print...</source>
        <translation>&amp;Pechatat&apos;...</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>Za&amp;kryt&apos;</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>Vy&amp;jti</translation>
    </message>
    <message>
        <source>&amp;Undo</source>
        <translation>Vern&amp;utsya</translation>
    </message>
    <message>
        <source>&amp;Redo</source>
        <translation>Pe&amp;redelat&apos;</translation>
    </message>
    <message>
        <source>&amp;Delete Objects</source>
        <translation>U&amp;dalit&apos; Objekty</translation>
    </message>
    <message>
        <source>Toggle &amp;Label</source>
        <translation>I&amp;zmenit&apos; vidimost&apos; nazvaniya</translation>
    </message>
    <message>
        <source>Hide Label</source>
        <translation>Spryatat&apos; Nazvanie</translation>
    </message>
    <message>
        <source>Show Label</source>
        <translation>Pokazat&apos; Nazvanie</translation>
    </message>
    <message>
        <source>Change La&amp;bel...</source>
        <translation>Izmenit&apos; &amp;Nazvanie...</translation>
    </message>
    <message>
        <source>&amp;Hide Objects</source>
        <translation>Spryac&amp;h Objekty</translation>
    </message>
    <message>
        <source>&amp;Unhide All</source>
        <translation>Pokazhi Vse &amp;Ukrytiye</translation>
    </message>
    <message>
        <source>&amp;Color</source>
        <translation>&amp;Cvet</translation>
    </message>
    <message>
        <source>Line &amp;Style</source>
        <translation>&amp;Stil&apos; Liniy</translation>
    </message>
    <message>
        <source>&amp;Point Style</source>
        <translation>Stil&apos; Toch&amp;ek</translation>
    </message>
    <message>
        <source>&amp;Font</source>
        <translation>Shri&amp;ft</translation>
    </message>
    <message>
        <source>Change &amp;Number of Samples...</source>
        <translation>Izmenit&apos; &amp;Kolichestvo Tochek...</translation>
    </message>
    <message>
        <source>&amp;Other...</source>
        <translation>Drug&amp;oy...</translation>
    </message>
    <message>
        <source>&amp;Font...</source>
        <translation>Shri&amp;ft...</translation>
    </message>
    <message>
        <source>&amp;Intersection Point</source>
        <translation>Tochka Peresechen&amp;iya</translation>
    </message>
    <message>
        <source>&amp;Segment</source>
        <translation>Otre&amp;zok</translation>
    </message>
    <message>
        <source>&amp;Midpoint</source>
        <translation>Seredinna&amp;ya Tochka</translation>
    </message>
    <message>
        <source>&amp;Ray</source>
        <translation>L&amp;uch</translation>
    </message>
    <message>
        <source>&amp;Line</source>
        <translation>&amp;Liniya</translation>
    </message>
    <message>
        <source>&amp;Perpendicular Line</source>
        <translation>&amp;Perpendikulyarnaya Liniya</translation>
    </message>
    <message>
        <source>&amp;Circle By Center And Point</source>
        <translation>Krug Po &amp;Centru I Tochke</translation>
    </message>
    <message>
        <source>&amp;Arc By Three Points</source>
        <translation>Dug&amp;a Po Trem Tochkam</translation>
    </message>
    <message>
        <source>Angle &amp;Bisector</source>
        <translation>&amp;Bisektrissa</translation>
    </message>
    <message>
        <source>L&amp;ocus</source>
        <translation>Puch&amp;ok</translation>
    </message>
    <message>
        <source>Poly&amp;gon</source>
        <translation>Mno&amp;gougol&apos;nik</translation>
    </message>
    <message>
        <source>Arc S&amp;ector</source>
        <translation>S&amp;ektor</translation>
    </message>
    <message>
        <source>Arc Se&amp;gment</source>
        <translation>Se&amp;gment</translation>
    </message>
    <message>
        <source>Circle I&amp;nterior</source>
        <translation>V&amp;nutrennost&apos; Kruga</translation>
    </message>
    <message>
        <source>&amp;Distance</source>
        <translation>&amp;Distancia</translation>
    </message>
    <message>
        <source>&amp;Length</source>
        <translation>D&amp;lina</translation>
    </message>
    <message>
        <source>&amp;Radius</source>
        <translation>&amp;Radius</translation>
    </message>
    <message>
        <source>&amp;Angle</source>
        <translation>&amp;Ugol</translation>
    </message>
    <message>
        <source>Ra&amp;tio</source>
        <translation>O&amp;tnoshenie</translation>
    </message>
    <message>
        <source>&amp;Slope</source>
        <translation>&amp;Naklon</translation>
    </message>
    <message>
        <source>Ar&amp;ea</source>
        <translation>&amp;Ploshad&apos;</translation>
    </message>
    <message>
        <source>&amp;Calculate...</source>
        <translation>Vy&amp;chislenie...</translation>
    </message>
    <message>
        <source>Choose &amp;Vector</source>
        <translation>Vybor &amp;Vektora</translation>
    </message>
    <message>
        <source>Choose &amp;Mirror</source>
        <translation>Vybor &amp;Zerkala</translation>
    </message>
    <message>
        <source>Choose &amp;Center</source>
        <translation>Vybor &amp;Centra</translation>
    </message>
    <message>
        <source>Choose &amp;Angle</source>
        <translation>Vybor Ugl&amp;a</translation>
    </message>
    <message>
        <source>Choose Rati&amp;o</source>
        <translation>Vybor &amp;Otnosheniya</translation>
    </message>
    <message>
        <source>C&amp;lear Chosen</source>
        <translation>U&amp;brat&apos; Vybor</translation>
    </message>
    <message>
        <source>&amp;Translate</source>
        <translation>&amp;Translirovat&apos;</translation>
    </message>
    <message>
        <source>R&amp;eflect</source>
        <translation>&amp;Otrazit&apos;</translation>
    </message>
    <message>
        <source>&amp;Scale</source>
        <translation>&amp;Gomotetiya</translation>
    </message>
    <message>
        <source>&amp;Rotate</source>
        <translation>Pove&amp;rnut&apos;</translation>
    </message>
    <message>
        <source>Make &amp;Normal</source>
        <translation>Sdelat&apos; &amp;Normal&apos;nym</translation>
    </message>
    <message>
        <source>Make &amp;Given</source>
        <translation>Sdelat&apos; &amp;Dannym</translation>
    </message>
    <message>
        <source>Make &amp;Final</source>
        <translation>Sdelat&apos; &amp;Konechnym</translation>
    </message>
    <message>
        <source>Make &amp;Initial</source>
        <translation>Sdelat&apos; Nachal&apos;n&amp;im</translation>
    </message>
    <message>
        <source>&amp;Recurse</source>
        <translation>&amp;Rekursiya</translation>
    </message>
    <message>
        <source>&amp;Quick Play</source>
        <translation>&amp;Skoryj Proigrysh</translation>
    </message>
    <message>
        <source>&amp;About...</source>
        <translation>&amp;O KSEGe...</translation>
    </message>
    <message>
        <source>&amp;Circumference</source>
        <translation>Dlinna O&amp;kruzhnosti</translation>
    </message>
    <message>
        <source>Arc &amp;Length</source>
        <translation>D&amp;lina Dugi</translation>
    </message>
    <message>
        <source>Toggle &amp;Labels</source>
        <translation>I&amp;zmenit&apos; vidimost&apos; nazvaniy</translation>
    </message>
    <message>
        <source>Hide Labels</source>
        <translation>Spryatat&apos; Nazvaniya</translation>
    </message>
    <message>
        <source>Show Labels</source>
        <translation>Pokazat&apos; Nazvaniya</translation>
    </message>
    <message>
        <source>&amp;Segments</source>
        <translation>Otre&amp;zki</translation>
    </message>
    <message>
        <source>&amp;Rays</source>
        <translation>L&amp;uchi</translation>
    </message>
    <message>
        <source>&amp;Midpoints</source>
        <translation>Seredinna&amp;yi Tochki</translation>
    </message>
    <message>
        <source>&amp;Intersection Points</source>
        <translation>Tochki Peresechen&amp;iya</translation>
    </message>
    <message>
        <source>&amp;Circle By Center And Radius</source>
        <translation>Krug Po &amp;Centru I Radiusu</translation>
    </message>
    <message>
        <source>&amp;Lines</source>
        <translation>&amp;Liniyi</translation>
    </message>
    <message>
        <source>Parallel &amp;Lines</source>
        <translation>Parallel&apos;niye &amp;Liniyi</translation>
    </message>
    <message>
        <source>Parallel &amp;Line</source>
        <translation>Parallel&apos;naya &amp;Liniya</translation>
    </message>
    <message>
        <source>&amp;Perpendicular Lines</source>
        <translation>&amp;Perpendikulyarnye Liniye</translation>
    </message>
    <message>
        <source>Untitled</source>
        <translation>Nenazvan</translation>
    </message>
    <message>
        <source>No Constructions</source>
        <translation>Net Postroeniy</translation>
    </message>
    <message>
        <source>Save?</source>
        <translation>Sohranit&apos;?</translation>
    </message>
    <message>
        <source>Would you like to save your changes?</source>
        <translation>Vy by hoteli sohranit&apos; svoi izmeneniya?</translation>
    </message>
    <message>
        <source>File Not Found</source>
        <translation>Fayl Ne Nayden</translation>
    </message>
    <message>
        <source>Sorry, I am afraid that file %1 does not exist.</source>
        <translation>Izvini, no ya boyus&apos; chto fayla %1 netu v etom mire.</translation>
    </message>
    <message>
        <source>Invalid file</source>
        <translation>Plohoy fayl</translation>
    </message>
    <message>
        <source>The file %1 does not look like a valid KSEG file.</source>
        <translation>Fayl %1 ne pohozh na horoshiy KSEGovskiy fayl.</translation>
    </message>
    <message>
        <source>About KSEG</source>
        <translation>O KSEGe</translation>
    </message>
    <message>
        <source>&amp;Change Directory...</source>
        <translation>Izmenit&apos; &amp;Direktoriyu...</translation>
    </message>
    <message>
        <source>Choose &amp;Language...</source>
        <translation>Vybo&amp;r Yazyka...</translation>
    </message>
    <message>
        <source>Language Change</source>
        <translation>Izmeneniye Yazyka</translation>
    </message>
    <message>
        <source>You will need to restart KSEG for the language change to fully take effect.</source>
        <translation>Vy dolzhny perezapustit&apos; KSEG chto-by izmeneniye yazyka voshlo v silu.</translation>
    </message>
    <message>
        <source>&amp;Delete Object</source>
        <translation>U&amp;dalit&apos; Objekt</translation>
    </message>
    <message>
        <source>&amp;Hide Object</source>
        <translation>Spryac&amp;h Objekt</translation>
    </message>
    <message>
        <source>Pr&amp;eferences...</source>
        <translation>P&amp;redpochteniya...</translation>
    </message>
    <message>
        <source>KSEG v0.4
Copyright (C) 1999-2003 Ilya Baran
http://www.mit.edu/~ibaran
ibaran@mit.edu</source>
        <translation>KSEG v0.4
Copyright (C) 1999-2003 Ilya Baran
http://www.mit.edu/~ibaran
ibaran@mit.edu</translation>
    </message>
    <message>
        <source>Open In Current Window...</source>
        <translation>Otkryt&apos; V Etom Okne...</translation>
    </message>
    <message>
        <source>Copy As Construction</source>
        <translation>Skopirovat&apos; Kak Postroenie</translation>
    </message>
    <message>
        <source>Selection &amp;Groups...</source>
        <translation>&amp;Gruppy Vybora...</translation>
    </message>
    <message>
        <source>&amp;Zoom</source>
        <translation>Uvelichenie (&amp;Z)</translation>
    </message>
    <message>
        <source>&amp;Pan</source>
        <translation>Dviganie Vida (&amp;P)</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation>&amp;Vid</translation>
    </message>
    <message>
        <source>Zoom To &amp;Fit</source>
        <translation>Uvelichenie Do Upora (&amp;F)</translation>
    </message>
    <message>
        <source>&amp;Original Zoom (100%)</source>
        <translation>Iznachal&apos;n&amp;oe Uvelichenie</translation>
    </message>
    <message>
        <source>E&amp;xport To Image...</source>
        <translation>E&amp;xportirovat&apos; kak kartinku...</translation>
    </message>
    <message>
        <source>Endpoints</source>
        <translation>Konechnye Tochki</translation>
    </message>
    <message>
        <source>Center Point</source>
        <translation>Tochka V Centre</translation>
    </message>
    <message>
        <source>Endpoint</source>
        <translation>Konechnaya Tochka</translation>
    </message>
    <message>
        <source>Zoom:</source>
        <translation>Uvelichenie:</translation>
    </message>
    <message>
        <source>Choose the File Format:</source>
        <translation>Vyberete Format Fayla:</translation>
    </message>
    <message>
        <source>High Quality Image</source>
        <translation>Kartinka Vysokogo Kachestva</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Exporting, Please wait...</source>
        <translation>Terpi, Ya Exportiruyu...</translation>
    </message>
</context>
<context>
    <name>MatrixDialog</name>
    <message>
        <source>Rows:</source>
        <translation>Ryadov:</translation>
    </message>
    <message>
        <source>Columns:</source>
        <translation>Kolonok:</translation>
    </message>
    <message>
        <source>Zero-Fill</source>
        <translation>Zapolnit&apos; Nulyami</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Otmena</translation>
    </message>
</context>
</TS>
